Simple tests
-------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/featherwing_ina219_simpletest.py
    :caption: examples/featherwing_ina219_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_joy_simpletest.py
    :caption: examples/featherwing_joy_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_alphanum_simpletest.py
    :caption: examples/featherwing_alphanum_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_dotstar_simpletest.py
    :caption: examples/featherwing_dotstar_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_neopixel_simpletest.py
    :caption: examples/featherwing_neopixel_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_sevensegment_simpletest.py
    :caption: examples/featherwing_sevensegment_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_rtc_simpletest.py
    :caption: examples/featherwing_rtc_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_gps_simpletest.py
    :caption: examples/featherwing_gps_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_matrix_simpletest.py
    :caption: examples/featherwing_matrix_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_minitft_simpletest.py
    :caption: examples/featherwing_minitft_simpletest.py
    :linenos:

.. literalinclude:: ../examples/featherwing_tempmotion_simpletest.py
    :caption: examples/featherwing_tempmotion_simpletest.py
    :linenos:

Other Examples
---------------

.. literalinclude:: ../examples/featherwing_dotstar_palette_example.py
    :caption: examples/featherwing_dotstar_palette_example.py
    :linenos:

.. literalinclude:: ../examples/featherwing_neopixel_palette_example.py
    :caption: examples/featherwing_neopixel_palette_example.py
    :linenos:
